@@ -24,7 +24,7 @@ require 'puppet/util/run_mode'
 # it's also a place to find top-level commands like 'debug'
 
 module Puppet
-  PUPPETVERSION = '2.6.4'
+  PUPPETVERSION = '2.6.14'
 
   def Puppet.version
     PUPPETVERSION
@@ -59,8 +59,7 @@ module Puppet
 
   # configuration parameter access and stuff
   def self.[](param)
-    case param
-    when :debug
+    if param == :debug
       return Puppet::Util::Log.level == :debug
     else
       return @@settings[param]
