@@ -1,12 +1,17 @@
+require 'time'
+
 require 'puppet/node'
 require 'puppet/indirector'
 
+require 'puppet/util/pson'
+
 # Manage a given node's facts.  This either accepts facts and stores them, or
 # returns facts for a given node.
 class Puppet::Node::Facts
   # Set up indirection, so that nodes can be looked for in
   # the node sources.
   extend Puppet::Indirector
+  extend Puppet::Util::Pson
 
   # We want to expire any cached nodes if the facts are saved.
   module NodeExpirer
@@ -54,6 +59,30 @@ class Puppet::Node::Facts
     strip_internal == other.send(:strip_internal)
   end
 
+  def timestamp=(time)
+    self.values[:_timestamp] = time
+  end
+
+  def timestamp
+    self.values[:_timestamp]
+  end
+
+  def self.from_pson(data)
+    result = new(data['name'], data['values'])
+    result.timestamp = Time.parse(data['timestamp'])
+    result.expiration = Time.parse(data['expiration'])
+    result
+  end
+
+  def to_pson(*args)
+    {
+      'expiration' => expiration,
+      'name' => name,
+      'timestamp' => timestamp,
+      'values' => strip_internal,
+    }.to_pson(*args)
+  end
+
   private
 
   # Add internal data to the facts for storage.
