@@ -6,8 +6,7 @@
 require File.dirname(__FILE__) + '/../../spec_helper'
 
 describe Puppet::Resource::Catalog do
-  describe "when pson is available" do
-    confine "PSON library is missing" => Puppet.features.pson?
+  describe "when pson is available", :if => Puppet.features.pson? do
     it "should support pson" do
       Puppet::Resource::Catalog.supported_formats.should be_include(:pson)
     end
