@@ -4,6 +4,8 @@ require File.dirname(__FILE__) + '/../../spec_helper'
 
 require 'puppet/application/apply'
 require 'puppet/file_bucket/dipper'
+require 'puppet/configurer'
+require 'fileutils'
 
 describe Puppet::Application::Apply do
   before :each do
@@ -51,11 +53,11 @@ describe Puppet::Application::Apply do
 
     before :each do
       Puppet::Log.stubs(:newdestination)
-      Puppet.stubs(:trap)
       Puppet::Log.stubs(:level=)
       Puppet.stubs(:parse_config)
       Puppet::FileBucket::Dipper.stubs(:new)
       STDIN.stubs(:read)
+      Puppet::Transaction::Report.stubs(:cache_class=)
 
       @apply.options.stubs(:[]).with(any_parameters)
     end
@@ -77,7 +79,7 @@ describe Puppet::Application::Apply do
     end
 
     it "should set INT trap" do
-      @apply.expects(:trap).with(:INT)
+      Signal.expects(:trap).with(:INT)
 
       @apply.setup
     end
@@ -113,6 +115,11 @@ describe Puppet::Application::Apply do
       lambda { @apply.setup }.should raise_error(SystemExit)
     end
 
+    it "should tell the report handler to cache locally as yaml" do
+      Puppet::Transaction::Report.expects(:cache_class=).with(:yaml)
+
+      @apply.setup
+    end
   end
 
   describe "when executing" do
@@ -166,38 +173,49 @@ describe Puppet::Application::Apply do
         @apply.expects(:exit).with(1)
         @apply.parseonly
       end
+
+      it "should exit with exit code 1 if error, even if --noop is set" do
+        Puppet[:noop] = true
+        @collection.stubs(:perform_initial_import).raises(Puppet::ParseError)
+        @apply.expects(:exit).with(1)
+        @apply.parseonly
+      end
     end
 
     describe "the main command" do
+      include PuppetSpec::Files
+
       before :each do
-        Puppet.stubs(:[])
-        Puppet.settings.stubs(:use)
-        Puppet.stubs(:[]).with(:prerun_command).returns ""
-        Puppet.stubs(:[]).with(:postrun_command).returns ""
-        Puppet.stubs(:[]).with(:trace).returns(true)
+        Puppet[:prerun_command] = ''
+        Puppet[:postrun_command] = ''
 
-        @apply.options.stubs(:[])
+        Puppet::Node::Facts.terminus_class = :memory
+        Puppet::Node.terminus_class = :memory
 
-        @facts = stub_everything 'facts'
-        Puppet::Node::Facts.stubs(:find).returns(@facts)
+        @facts = Puppet::Node::Facts.new(Puppet[:node_name_value])
+        @facts.save
 
-        @node = stub_everything 'node'
-        Puppet::Node.stubs(:find).returns(@node)
+        @node = Puppet::Node.new(Puppet[:node_name_value])
+        @node.save
 
-        @catalog = stub_everything 'catalog'
+        @catalog = Puppet::Resource::Catalog.new
         @catalog.stubs(:to_ral).returns(@catalog)
+
         Puppet::Resource::Catalog.stubs(:find).returns(@catalog)
 
         STDIN.stubs(:read)
 
-        @transaction = stub_everything 'transaction'
+        @apply.stubs(:exit)
+
+        @transaction = Puppet::Transaction.new(@catalog)
         @catalog.stubs(:apply).returns(@transaction)
 
-        @apply.stubs(:exit)
+        Puppet::Util::Storage.stubs(:load)
+        Puppet::Configurer.any_instance.stubs(:save_last_run_summary) # to prevent it from trying to write files
       end
 
       it "should set the code to run from --code" do
-        @apply.options.stubs(:[]).with(:code).returns("code to run")
+        @apply.options[:code] = "code to run"
         Puppet.expects(:[]=).with(:code,"code to run")
 
         @apply.main
@@ -213,49 +231,60 @@ describe Puppet::Application::Apply do
       end
 
       it "should set the manifest if a file is passed on command line and the file exists" do
-        File.stubs(:exist?).with('site.pp').returns true
-        @apply.command_line.stubs(:args).returns(['site.pp'])
+        manifest = tmpfile('site.pp')
+        FileUtils.touch(manifest)
+        @apply.command_line.stubs(:args).returns([manifest])
 
-        Puppet.expects(:[]=).with(:manifest,"site.pp")
+        Puppet.expects(:[]=).with(:manifest,manifest)
 
         @apply.main
       end
 
       it "should raise an error if a file is passed on command line and the file does not exist" do
-        File.stubs(:exist?).with('noexist.pp').returns false
-        @apply.command_line.stubs(:args).returns(['noexist.pp'])
-        lambda { @apply.main }.should raise_error(RuntimeError, 'Could not find file noexist.pp')
+        noexist = tmpfile('noexist.pp')
+        @apply.command_line.stubs(:args).returns([noexist])
+        lambda { @apply.main }.should raise_error(RuntimeError, "Could not find file #{noexist}")
       end
 
       it "should set the manifest to the first file and warn other files will be skipped" do
-        File.stubs(:exist?).with('starwarsIV').returns true
-        File.expects(:exist?).with('starwarsI').never
-        @apply.command_line.stubs(:args).returns(['starwarsIV', 'starwarsI', 'starwarsII'])
+        manifest = tmpfile('starwarsIV')
+        FileUtils.touch(manifest)
 
-        Puppet.expects(:[]=).with(:manifest,"starwarsIV")
+        @apply.command_line.stubs(:args).returns([manifest, 'starwarsI', 'starwarsII'])
+
+        Puppet.expects(:[]=).with(:manifest,manifest)
         Puppet.expects(:warning).with('Only one file can be applied per run.  Skipping starwarsI, starwarsII')
 
         @apply.main
       end
 
-      it "should collect the node facts" do
-        Puppet::Node::Facts.expects(:find).returns(@facts)
+      it "should set the facts name based on the node_name_fact" do
+        @facts = Puppet::Node::Facts.new(Puppet[:node_name_value], 'my_name_fact' => 'other_node_name')
+        @facts.save
+        Puppet::Node.new('other_node_name').save
+        Puppet[:node_name_fact] = 'my_name_fact'
 
         @apply.main
+
+        @facts.name.should == 'other_node_name'
       end
 
-      it "should raise an error if we can't find the node" do
+      it "should set the node_name_value based on the node_name_fact" do
+        Puppet::Node::Facts.new(Puppet[:node_name_value], 'my_name_fact' => 'other_node_name').save
+        Puppet::Node.new('other_node_name').save
+        Puppet[:node_name_fact] = 'my_name_fact'
+
+        @apply.main
+
+        Puppet[:node_name_value].should == 'other_node_name'
+      end
+
+      it "should raise an error if we can't find the facts" do
         Puppet::Node::Facts.expects(:find).returns(nil)
 
         lambda { @apply.main }.should raise_error
       end
 
-      it "should look for the node" do
-        Puppet::Node.expects(:find).returns(@node)
-
-        @apply.main
-      end
-
       it "should raise an error if we can't find the node" do
         Puppet::Node.expects(:find).returns(nil)
 
@@ -263,21 +292,20 @@ describe Puppet::Application::Apply do
       end
 
       it "should merge in our node the loaded facts" do
-        @facts.stubs(:values).returns("values")
-
-        @node.expects(:merge).with("values")
+        @facts.values = {'key' => 'value'}
 
         @apply.main
+
+        @node.parameters['key'].should == 'value'
       end
 
       it "should load custom classes if loadclasses" do
-        @apply.options.stubs(:[]).with(:loadclasses).returns(true)
-        Puppet.stubs(:[]).with(:classfile).returns("/etc/puppet/classes.txt")
-        FileTest.stubs(:exists?).with("/etc/puppet/classes.txt").returns(true)
-        FileTest.stubs(:readable?).with("/etc/puppet/classes.txt").returns(true)
-        File.stubs(:read).with("/etc/puppet/classes.txt").returns("class")
+        @apply.options[:loadclasses] = true
+        classfile = tmpfile('classfile')
+        File.open(classfile, 'w') { |c| c.puts 'class' }
+        Puppet[:classfile] = classfile
 
-        @node.expects(:classes=)
+        @node.expects(:classes=).with(['class'])
 
         @apply.main
       end
@@ -302,11 +330,8 @@ describe Puppet::Application::Apply do
       end
 
       it "should call the prerun and postrun commands on a Configurer instance" do
-        configurer = stub 'configurer'
-
-        Puppet::Configurer.expects(:new).returns configurer
-        configurer.expects(:execute_prerun_command)
-        configurer.expects(:execute_postrun_command)
+        Puppet::Configurer.any_instance.expects(:execute_prerun_command)
+        Puppet::Configurer.any_instance.expects(:execute_postrun_command)
 
         @apply.main
       end
@@ -318,19 +343,28 @@ describe Puppet::Application::Apply do
       end
 
       describe "with detailed_exitcodes" do
+        before :each do
+          @apply.options[:detailed_exitcodes] = true
+        end
+
         it "should exit with report's computed exit status" do
-          Puppet.stubs(:[]).with(:noop).returns(false)
-          @apply.options.stubs(:[]).with(:detailed_exitcodes).returns(true)
-          report = stub 'report', :exit_status => 666
-          @transaction.stubs(:report).returns(report)
+          Puppet[:noop] = false
+          Puppet::Transaction::Report.any_instance.stubs(:exit_status).returns(666)
+          @apply.expects(:exit).with(666)
+
+          @apply.main
+        end
+
+        it "should exit with report's computed exit status, even if --noop is set" do
+          Puppet[:noop] = true
+          Puppet::Transaction::Report.any_instance.stubs(:exit_status).returns(666)
           @apply.expects(:exit).with(666)
 
           @apply.main
         end
 
         it "should always exit with 0 if option is disabled" do
-          Puppet.stubs(:[]).with(:noop).returns(false)
-          @apply.options.stubs(:[]).with(:detailed_exitcodes).returns(false)
+          Puppet[:noop] = false
           report = stub 'report', :exit_status => 666
           @transaction.stubs(:report).returns(report)
           @apply.expects(:exit).with(0)
@@ -339,8 +373,7 @@ describe Puppet::Application::Apply do
         end
 
         it "should always exit with 0 if --noop" do
-          Puppet.stubs(:[]).with(:noop).returns(true)
-          @apply.options.stubs(:[]).with(:detailed_exitcodes).returns(true)
+          Puppet[:noop] = true
           report = stub 'report', :exit_status => 666
           @transaction.stubs(:report).returns(report)
           @apply.expects(:exit).with(0)
