@@ -10,10 +10,10 @@ describe provider_class do
     @provider = provider_class.new(@resource)
   end
 
-  # #1360
   it "should add -o when allowdupe is enabled and the group is being created" do
     @resource.stubs(:should).returns "fakeval"
     @resource.stubs(:[]).returns "fakeval"
+    @resource.stubs(:system?).returns true
     @resource.expects(:allowdupe?).returns true
     @provider.expects(:execute).with { |args| args.include?("-o") }
 
@@ -28,4 +28,14 @@ describe provider_class do
 
     @provider.gid = 150
   end
+
+  it "should add -r when system is enabled and the group is being created" do
+    @resource.stubs(:should).returns "fakeval"
+    @resource.stubs(:[]).returns "fakeval"
+    @resource.expects(:system?).returns true
+    @resource.stubs(:allowdupe?).returns true
+    @provider.expects(:execute).with { |args| args.include?("-r") }
+
+    @provider.create
+  end
 end
