@@ -5,9 +5,7 @@ require File.dirname(__FILE__) + '/../../spec_helper'
 augeas = Puppet::Type.type(:augeas)
 
 describe augeas do
-  describe "when augeas is present" do
-    confine "Augeas is unavailable" => Puppet.features.augeas?
-
+  describe "when augeas is present", :if => Puppet.features.augeas? do
     it "should have a default provider inheriting from Puppet::Provider" do
       augeas.defaultprovider.ancestors.should be_include(Puppet::Provider)
     end
