@@ -4,8 +4,6 @@ require File.dirname(__FILE__) + '/../lib/puppettest'
 
 require 'puppet'
 require 'puppet/parser/parser'
-require 'puppet/network/client'
-require 'puppet/network/handler'
 require 'puppettest'
 
 class TestSnippets < Test::Unit::TestCase
@@ -37,6 +35,9 @@ class TestSnippets < Test::Unit::TestCase
   end
 
   def assert_mode_equal(mode, path)
+    if mode.is_a? Integer
+      mode = mode.to_s(8)
+    end
     unless file = @catalog.resource(:file, path)
       raise "Could not find file #{path}"
     end
@@ -66,13 +67,6 @@ class TestSnippets < Test::Unit::TestCase
     ast
   end
 
-  def client
-    args = {
-      :Listen => false
-    }
-    Puppet::Network::Client.new(args)
-  end
-
   def ast2scope(ast)
     scope = Puppet::Parser::Scope.new
     ast.evaluate(scope)
