@@ -227,66 +227,6 @@ class TestFileSources < Test::Unit::TestCase
     file
   end
 
-  def test_unmountedNetworkSources
-    server = nil
-    mounts = {
-      "/" => "root",
-      "/noexistokay" => "noexist"
-    }
-
-    fileserverconf = mkfileserverconf(mounts)
-
-    Puppet[:autosign] = true
-    Puppet[:masterport] = @port
-    Puppet[:certdnsnames] = "localhost"
-
-    serverpid = nil
-    assert_nothing_raised("Could not start on port #{@port}") {
-
-            server = Puppet::Network::HTTPServer::WEBrick.new(
-                
-        :Port => @port,
-        
-        :Handlers => {
-          :CA => {}, # so that certs autogenerate
-          :FileServer => {
-            :Config => fileserverconf
-          }
-        }
-      )
-
-    }
-
-    serverpid = fork {
-      assert_nothing_raised {
-        #trap(:INT) { server.shutdown; Kernel.exit! }
-        trap(:INT) { server.shutdown }
-        server.start
-      }
-    }
-    @@tmppids << serverpid
-
-    sleep(1)
-
-    name = File.join(tmpdir, "nosourcefile")
-
-          file = Puppet::Type.type(:file).new(
-                
-      :source => "puppet://localhost/noexist/file",
-        
-      :name => name
-    )
-
-    assert_raise Puppet::Error do
-      file.retrieve
-    end
-
-    comp = mk_catalog(file)
-    comp.apply
-
-    assert(!FileTest.exists?(name), "File with no source exists anyway")
-  end
-
   def test_sourcepaths
     files = []
     3.times {
@@ -327,12 +267,9 @@ class TestFileSources < Test::Unit::TestCase
 
     file = nil
     assert_nothing_raised {
-
-            file = Puppet::Type.type(:file).new(
-                
+      file = Puppet::Type.type(:file).new(
         :name => dest,
         :ensure => "file",
-        
         :source => source
       )
     }
